@@ -16,11 +16,6 @@ consoleHandle = logging.StreamHandler()
 consoleHandle.setFormatter(logging.Formatter('%(name)s %(levelname)s: %(message)s'))
 _logger.addHandler(consoleHandle)
 
-from .treatment import Spectrum, MaskInspector, CubeInspector
-from .io import *
-from .tools import label_decomposition, LineFinder, spectral_mask_generator
-from .plots import spatial_mask_generator
-
 # Get python version being used
 __python_version__ = sys.version_info
 
@@ -31,6 +26,13 @@ _setup_cfg.optionxform = str
 _setup_cfg.read(os.path.join(_dir_path, 'config.cfg'))
 
 __version__ = _setup_cfg['metadata']['version']
+_lines_database_path = (os.path.join(_dir_path, '/resources/parent_mask.txt'))
 
 # Logging configuration
 _logger.debug(f'Launching LiMe {__version__} in Python {__python_version__}')
+
+from .treatment import Spectrum, Sample, MaskInspector, CubeInspector
+from .io import *
+from .tools import label_decomposition, LineFinder, spectral_mask_generator
+from .plots import spatial_mask_generator
+
